@@ -776,7 +776,7 @@ def _source_package_checks(
             kvpair.range_in_parent().relative_to(stanza_position),
             f'Multiple Version Control fields defined ("{kvpair.field_name}")',
             "warning",
-            "debputy",
+            "Policy 5.6.26",
             quickfixes=[
                 propose_remove_range_quick_fix(
                     proposed_title=f'Remove "{kvpair.field_name}"'
@@ -954,7 +954,7 @@ def _diagnostics_for_stanza(
                     f'The {field_name} is defined for use in the "{intended_usage}" stanza.'
                     f" Please move it to the right place or remove it",
                     "error",
-                    "debputy",
+                    known_else_where.missing_field_authority,
                 )
             continue
 
@@ -963,7 +963,7 @@ def _diagnostics_for_stanza(
                 field_range,
                 f"The {field_name} has no value. Either provide a value or remove it.",
                 "error",
-                "debputy",
+                "Policy 5.1",
             )
             continue
         known_field.field_diagnostics(
@@ -1016,7 +1016,7 @@ def _diagnostics_for_stanza(
                 dup_range,
                 f"The {normalized_field_name} field name was used multiple times in this stanza.",
                 "error",
-                "debputy",
+                "Policy 5.1",
                 related_information=related_information,
             )
 
@@ -1071,6 +1071,7 @@ def _scan_for_syntax_errors_and_token_level_diagnostics(
                     "spelling",
                     "debputy",
                     quickfixes=[propose_correct_text_quick_fix(c) for c in corrections],
+                    enable_non_interactive_auto_fix=False,
                 )
     return first_error
 
@@ -1316,13 +1317,13 @@ def _reformat_debian_control(
 
 
 @lsp_format_document(_DISPATCH_RULE)
-def _debian_control_on_save_formatting(
+def _debian_control_format_file(
     ls: "DebputyLanguageServer",
     params: DocumentFormattingParams,
 ) -> Optional[Sequence[TextEdit]]:
     doc = ls.workspace.get_text_document(params.text_document.uri)
     lint_state = ls.lint_state(doc)
-    return deb822_format_file(lint_state, _DCTRL_FILE_METADATA)
+    return _reformat_debian_control(lint_state)
 
 
 @lsp_semantic_tokens_full(_DISPATCH_RULE)
