@@ -189,7 +189,7 @@ def _diagnostics_for_stanza(
                 field_range,
                 f"The {field_name} has no value. Either provide a value or remove it.",
                 "error",
-                "debputy",
+                "Policy 5.1",
             )
             continue
         if known_field is None:
@@ -230,7 +230,7 @@ def _diagnostics_for_stanza(
                 f"The {normalized_field_name} field name was used multiple times in this stanza."
                 f" Please ensure the field is only used once per stanza.",
                 "error",
-                "debputy",
+                "Policy 5.1",
                 related_information=related_information,
             )
 
@@ -285,6 +285,7 @@ def _scan_for_syntax_errors_and_token_level_diagnostics(
                     "spelling",
                     "debputy",
                     quickfixes=[propose_correct_text_quick_fix(c) for c in corrections],
+                    enable_non_interactive_auto_fix=False,
                 )
     return first_error
 
