@@ -54,7 +54,6 @@ from debputy.util import run_build_system_command, _debug_log, _info, _warn
 if TYPE_CHECKING:
     from debputy.build_support.build_context import BuildContext
     from debputy.highlevel_manifest import HighLevelManifest
-    from debputy.plugin.api.impl_types import DIPHandler
 
 
 AT = TypeVar("AT")
@@ -262,6 +261,9 @@ class BuildRule(DebputyDispatchableType):
             return self.auto_generated_stem
         return name
 
+    def install_dest_dir(self) -> Optional[str]:
+        return None
+
 
 def _is_type_or_none(v: Optional[Any], expected_type: Type[AT]) -> Optional[AT]:
     if isinstance(v, expected_type):
@@ -458,6 +460,13 @@ class StepBasedBuildSystemRule(BuildSystemRule):
         if not isinstance(dest_dir, BinaryPackage):
             clean_helper.schedule_removal_of_directories(dest_dir)
 
+    @final
+    def install_dest_dir(self) -> Optional[str]:
+        dest_dir = self.resolve_dest_dir()
+        if isinstance(dest_dir, BinaryPackage):
+            return None
+        return dest_dir
+
     @final
     def perform_build(
         self,
@@ -798,11 +807,7 @@ class NinjaBuildSupport:
         # debhelper never had parallel installs, so we do not have it either for now.
         enable_parallelization: bool = False,
     ) -> None:
-        install_env_mod = EnvironmentModification(
-            replacements={
-                "DESTDIR": dest_dir,
-            }
-        )
+        install_env_mod = EnvironmentModification(replacements=(("DESTDIR", dest_dir),))
         if env_mod is not None:
             install_env_mod = install_env_mod.combine(env_mod)
         self._run_ninja(
@@ -846,11 +851,7 @@ class NinjaBuildSupport:
             else 1
         )
         extra_ninja_args.append(f"-j{limit}")
-        ninja_env_mod = EnvironmentModification(
-            replacements={
-                "LC_ALL": "C.UTF-8",
-            }
-        )
+        ninja_env_mod = EnvironmentModification(replacements=(("LC_ALL", "C.UTF-8"),))
         if env_mod is not None:
             ninja_env_mod = ninja_env_mod.combine(env_mod)
         run_build_system_command(
@@ -990,8 +991,8 @@ def debputy_build_system(
 ) -> Callable[[Type[BSPF]], Type[BSPF]]:
     if not isinstance(provider, type) or not issubclass(provider, BuildSystemRule):
         raise PluginInitializationError(
-            f"The provider for @{debputy_build_system.__name__} must be subclass of {BuildSystemRule.__name__}goes on the TypedDict that defines the parsed"
-            f" variant of the manifest definition. Not the build system implementation class."
+            f"The provider parameter for @{debputy_build_system.__name__} must be subclass of"
+            f" {BuildSystemRule.__name__}."
         )
 
     def _constructor_wrapper(
