@@ -1336,8 +1336,7 @@ def test_dctrl_duplicate_key(line_linter: LintWrapper) -> None:
         Source: jquery-tablesorter
         Section: javascript
         Priority: optional
-        Maintainer: Debian Javascript Maintainers <pkg-javascript-devel@lists.alioth.de\
-        bian.org>
+        Maintainer: Debian Javascript Maintainers <pkg-javascript-devel@lists.alioth.debian.org>
         Uploaders: Paul Gevers <elbrus@debian.org>
         Build-Depends:
          debhelper-compat (=13),
@@ -1629,6 +1628,38 @@ def test_uploaders_field(line_linter: LintWrapper, uploaders: str) -> None:
     assert not diagnostics
 
 
+def test_maintainer_trailing_comma_bug_1089649(line_linter: LintWrapper) -> None:
+    lines = textwrap.dedent(
+        f"""\
+    Source: foo
+    Section: devel
+    Priority: optional
+    Standards-Version: {CURRENT_STANDARDS_VERSION}
+    Maintainer: Jane Developer <jane@example.com>,
+    Build-Depends: debhelper-compat (= 13)
+    Homepage: https://example.com
+
+    Package: foo
+    Architecture: all
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+    """
+    ).splitlines(keepends=True)
+
+    diagnostics = line_linter(lines)
+    print(diagnostics)
+    assert diagnostics and len(diagnostics) == 1
+    issue = diagnostics[0]
+
+    msg = 'The "Maintainer" field has a trailing seperator, but it is a single value field.'
+    assert issue.message == msg
+    assert f"{issue.range}" == f"4:45-4:46"
+    assert issue.severity == DiagnosticSeverity.Error
+
+
 def test_uploaders_field_no_email(line_linter: LintWrapper) -> None:
     lines = textwrap.dedent(
         f"""\
@@ -1696,6 +1727,8 @@ def test_spellcheck_ignore_package_names(
     assert issue.message == msg
     assert f"{issue.range}" == f"16:10-16:17"
     assert issue.severity == DiagnosticSeverity.Hint
+    assert "enable_non_interactive_auto_fix" in issue.data
+    assert not issue.data["enable_non_interactive_auto_fix"]
 
     lines = textwrap.dedent(
         f"""\
